@@ -20,6 +20,9 @@
 
 #include "usbprogApp.h"
 #include "usbprogFrm.h"
+#ifdef __APPLE__
+#include <ApplicationServices/ApplicationServices.h>
+#endif
 
 using std::cerr;
 using std::endl;
@@ -72,6 +75,15 @@ bool usbprogFrmApp::OnInit()
     usbprogFrm* frame = new usbprogFrm(NULL);
     frame->Show(true);
     SetTopWindow(frame);
+
+#ifdef __APPLE__
+    // this is necessary because of
+    // http://wiki.wxwidgets.org/WxMac_Issues#My_app_can.27t_be_brought_to_the_front.21
+    ProcessSerialNumber PSN;
+    GetCurrentProcess(&PSN);
+    TransformProcessType(&PSN, kProcessTransformToForegroundApplication);
+#endif
+
     return true;
 }
 
